@@ -7,25 +7,29 @@ from torch.autograd import Variable
 
 from transvae.tvae_util import *
 
-def vae_data_gen(data, char_dict):
+def vae_data_gen(mols, props, char_dict):
     """
     Encodes input smiles to tensors with token ids
 
     Arguments:
-        data (np.array, req): Array containing input SMILES strings
+        mols (np.array, req): Array containing input molecular structures
+        props (np.array, req): Array containing scalar chemical property values
         char_dict (dict, req): Dictionary mapping tokens to integer id
     Returns:
         encoded_data (torch.tensor): Tensor containing encodings for each
                                      SMILES string
     """
-    smiles = data[:,0]
-    del data
+    smiles = mols[:,0]
+    if props is None:
+        props = np.zeros(smiles.shape)
+    del mols
     smiles = [smi_tokenizer(x) for x in smiles]
-    encoded_data = torch.empty((len(smiles), 127))
+    encoded_data = torch.empty((len(smiles), 128))
     for j, smi in enumerate(smiles):
         encoded_smi = encode_smiles(smi, 126, char_dict)
         encoded_smi = [0] + encoded_smi
-        encoded_data[j,:] = torch.tensor(encoded_smi)
+        encoded_data[j,:-1] = torch.tensor(encoded_smi)
+        encoded_data[j,-1] = torch.tensor(props[j])
     return encoded_data
 
 def make_std_mask(tgt, pad):
